Module blaxel.models.function_schema
====================================

Classes
-------

`FunctionSchema(all_of: blaxel.types.Unset | list[typing.Any] = <blaxel.types.Unset object>, any_of: blaxel.types.Unset | list[typing.Any] = <blaxel.types.Unset object>, description: blaxel.types.Unset | str = <blaxel.types.Unset object>, enum: blaxel.types.Unset | list[str] = <blaxel.types.Unset object>, format_: blaxel.types.Unset | str = <blaxel.types.Unset object>, items: blaxel.types.Unset | ForwardRef('FunctionSchema') = <blaxel.types.Unset object>, max_length: blaxel.types.Unset | float = <blaxel.types.Unset object>, maximum: blaxel.types.Unset | float = <blaxel.types.Unset object>, min_length: blaxel.types.Unset | float = <blaxel.types.Unset object>, minimum: blaxel.types.Unset | float = <blaxel.types.Unset object>, not_: blaxel.types.Unset | ForwardRef('FunctionSchemaNot') = <blaxel.types.Unset object>, one_of: blaxel.types.Unset | list[typing.Any] = <blaxel.types.Unset object>, pattern: blaxel.types.Unset | str = <blaxel.types.Unset object>, properties: blaxel.types.Unset | ForwardRef('FunctionSchemaProperties') = <blaxel.types.Unset object>, required: blaxel.types.Unset | list[str] = <blaxel.types.Unset object>, title: blaxel.types.Unset | str = <blaxel.types.Unset object>, type_: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Function schema
    
    Attributes:
        all_of (Union[Unset, list[Any]]): List of schemas that this schema extends
        any_of (Union[Unset, list[Any]]): List of possible schemas, any of which this schema could be
        description (Union[Unset, str]): Description of the schema
        enum (Union[Unset, list[str]]): Enum values
        format_ (Union[Unset, str]): Format of the schema
        items (Union[Unset, FunctionSchema]): Function schema
        max_length (Union[Unset, float]): Maximum length for string types
        maximum (Union[Unset, float]): Maximum value for number types
        min_length (Union[Unset, float]): Minimum length for string types
        minimum (Union[Unset, float]): Minimum value for number types
        not_ (Union[Unset, FunctionSchemaNot]): Schema that this schema must not be
        one_of (Union[Unset, list[Any]]): List of schemas, one of which this schema must be
        pattern (Union[Unset, str]): Pattern for string types
        properties (Union[Unset, FunctionSchemaProperties]): Properties of the schema
        required (Union[Unset, list[str]]): Required properties of the schema
        title (Union[Unset, str]): Title of the schema
        type_ (Union[Unset, str]): Type of the schema
    
    Method generated by attrs for class FunctionSchema.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `all_of`
    :

    `any_of`
    :

    `description`
    :

    `enum`
    :

    `format_`
    :

    `items`
    :

    `max_length`
    :

    `maximum`
    :

    `min_length`
    :

    `minimum`
    :

    `not_`
    :

    `one_of`
    :

    `pattern`
    :

    `properties`
    :

    `required`
    :

    `title`
    :

    `type_`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :